@@ -8,11 +8,15 @@
 
 /* Compile Time Versioning Information */
 
-#define LIBNL_STRING "libnl 3.6.0"
-#define LIBNL_VERSION "3.6.0"
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+#define LIBNL_STRING "libnl 3.8.0"
+#define LIBNL_VERSION "3.8.0"
 
 #define LIBNL_VER_MAJ		3
-#define LIBNL_VER_MIN		6
+#define LIBNL_VER_MIN		8
 #define LIBNL_VER_MIC		0
 #define LIBNL_VER(maj,min)	((maj) << 8 | (min))
 #define LIBNL_VER_NUM		LIBNL_VER(LIBNL_VER_MAJ, LIBNL_VER_MIN)
@@ -28,4 +32,8 @@ extern const int        nl_ver_maj;
 extern const int        nl_ver_min;
 extern const int        nl_ver_mic;
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
